%global momorel 7

Summary: DHCPv6 - DHCP server and client for IPv6
Name:    dhcpv6
Version: 0.10
Release: %{momorel}m%{?dist}
License: GPL 
Group:   System Environment/Daemons
URL:     http://dhcpv6.sourceforge.net/
Source0: http://dl.sourceforge.net/sourceforge/dhcpv6/dhcp-%{version}.tgz
Source1: libdhcp6client.pc
Source2: rfc3315.txt

Patch0:  dhcpv6-0.10-redhat.patch
Patch1:  dhcpv6-0.10-relay.patch
Patch2:  dhcpv6-0.10-man.patch
Patch3:  dhcpv6-0.10-gethwid.patch
Patch4:  dhcpv6-0.10-no-strlcat.patch

Patch99: dhcpv6-0.10-libdhcp6client.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-root
Prereq: chkconfig, initscripts
BuildRequires: flex, bison, openssl-devel, autoconf, automake, libtool

%description
Implements the Dynamic Host Configuration Protocol (DHCP) for 
Internet Protocol version 6 (IPv6) networks in accordance with 
RFC 3315 : Dynamic Host Configuration Protocol for IPv6 (DHCPv6).
Consists of dhcp6s(8), the server DHCP daemon, and dhcp6r(8),
the DHCPv6 relay agent. 
Install this if you want to support dynamic configuration of
IPv6 addresses and parameters on your IPv6 network.
See man dhcp6s(8), dhcp6r(8), dhcp6s.conf(5),
and the documentation in /usr/share/doc/dhcpv6* .

%package -n dhcpv6_client
Summary:  DHCPv6 client
Requires: initscripts >= 7.73
Group: System Environment/Base

%description -n dhcpv6_client
Provides the client for the DHCPv6 protocol (RFC 3315) to support
dynamic configuration of IPv6 addresses and parameters.
See man dhcp6c(8), dhcp6c.conf(5), and the documentation in
/usr/share/dhcpv6_client* .

%package -n libdhcp6client
Summary: The DHCPv6 client in a library for invocation by other programs
Group:  Development/Libraries

%description -n libdhcp6client
Provides the client for the DHCPv6 protocol (RFC 3315) to support
dynamic configuration of IPv6 addresses and parameters, in a 
library for invocation by other programs.

%package -n libdhcp6client-devel
Summary: Header files for development with the DHCPv6 client library.
Group:   Development/Libraries

%description -n libdhcp6client-devel
Header files for development with the DHCPv6 client library.

%prep
%setup -q -n dhcp-%{version}
%patch0 -p1 -b .rh
%patch1 -p1 -b .relay
%patch2 -p1 -b .man
%patch3 -p1 -b .gethwid
%patch4 -p1 -b .no_strlcat
 
%patch99 -p1 -b .libdhcp6client
 
cp -fp %{SOURCE2} docs

# these things are part of glibc
rm -f ifaddrs.c ifaddrs.h queue.h

# we don't need these things
rm -f strlcat.c

rm -f configure
autoreconf -if

%build
%configure --prefix=/ --mandir=%{_mandir}
make
make -C libdhcp6client

%install
rm -rf $RPM_BUILD_ROOT
sed 's/@DHCPV6_VERSION@/'%{version}'/' < %{SOURCE1} > libdhcp6client.pc
%{__make} install DESTDIR=$RPM_BUILD_ROOT \
                  LIBDIR=%{_libdir} \
                  initdir=%{_sysconfdir}/init.d/ \
                  PKGCFGDIR=%{_libdir}/pkgconfig \
                  INSTALL_USER=`id -nu` INSTALL_GROUP=`id -gn`
%{__make} -C libdhcp6client install DESTDIR=$RPM_BUILD_ROOT \
             LIBDIR=%{_libdir} \
             PKGCFGDIR=%{_libdir}/pkgconfig \
             INSTALL_USER=`id -nu` INSTALL_GROUP=`id -gn` \
	     initdir=%{_sysconfdir}/init.d

mkdir -p %{buildroot}%{_localstatedir}/lib/dhcpv6

%post
chkconfig --add dhcp6s

%preun
if [ $1 = 0 ]; then
  service dhcp6s stop > /dev/null 2>&1
  chkconfig --del dhcp6s
fi

%postun
if [ "$1" -ge "1" ]; then
  service dhcp6s condrestart >/dev/null 2>&1
fi
exit 0

%post -n libdhcp6client -p /sbin/ldconfig

%postun -n libdhcp6client -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root,-)
%attr(754,root,root) %{_sbindir}/dhcp6s
%attr(754,root,root) %{_sbindir}/dhcp6r
%attr(755,root,root) %config /etc/init.d/dhcp6s
%attr(755,root,root) %config /etc/init.d/dhcp6r
%config(noreplace) /etc/sysconfig/dhcp6s
%config(noreplace) /etc/sysconfig/dhcp6r
%{_mandir}/man8/dhcp6s.8.*
%{_mandir}/man5/dhcp6s.conf.5.*
%{_mandir}/man8/dhcp6r.8.*
%doc ReadMe docs/* dhcp6s.conf server6_addr.conf

%files -n dhcpv6_client
%defattr(-,root,root,-)
%attr(750,root,root) /sbin/dhcp6c
%{_mandir}/man8/dhcp6c.8.*
%{_mandir}/man5/dhcp6c.conf.5.*
%doc ReadMe dhcp6c.conf
%attr(750,root,root) %dir %{_localstatedir}/lib/dhcpv6

%files -n libdhcp6client
%defattr(-,root,root,-)
%{_libdir}/libdhcp6client-%{version}.so.*

%files -n libdhcp6client-devel
%defattr(0644,root,root,0755)
%{_includedir}/*
%{_libdir}/pkgconfig/libdhcp6client.pc
%defattr(-,root,root,-)
%{_libdir}/libdhcp6client.so
%{_libdir}/libdhcp6client.a


%changelog
* Tue Feb 20 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-7m)
- sync fc-devel (0.10-40)

* Wed Jan 24 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-6m)
- sync fc-devel (0.10-35)

* Sun Jul  2 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-5m)
- sync fc-devel

* Sat Jun 24 2006 Yohsuke Ooi <meke@momonga-linux.org>
- (0.10-4m)
- sync fc-devel

* Sat Jun 10 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.10-3m)
- delete duplicate dir

* Fri Jun  9 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (0.10-2m)
- delete duplicate dirs %%dir %%{_localstatedir}/lib/dhcpv6
- re-add %%dir %%{_localstatedir}/lib/dhcpv6
  because dhcpv6 pkg is not required by dhcpv6_clinets pkg

* Thu Jun  8 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.10-1m)
- import from FC5

* Fri Feb 10 2006 Jesse Keating <jkeating@redhat.com> - 0.10-16.1
- bump again for double-long bug on ppc(64)

* Tue Feb 07 2006 Jason Vas Dias <jvdias@redhat.com> - 0.10-16
- rebuild for new gcc, glibc, glibc-kernheaders

* Sun Dec 18 2005 Jason Vas Dias<jvdias@redhat.com> - 0.10-15.2
- rebuild for new gcc & flex

* Fri Dec 09 2005 Jesse Keating <jkeating@redhat.com>
- rebuilt

* Wed Nov  9 2005 Tomas Mraz <tmraz@redhat.com> - 0.10-15
- rebuilt with new openssl

* Mon Aug 15 2005 Jason Vas Dias <jvdias@redhat.com>
- fix bug 165882: allow client to configure an interface which
  does not have an IPv4 address ( use getifaddrs instead of
  ioctl(sockfd, SIOGIFCONF, ...)
- fix bug 165884 (possibly!): force use of glibc's getifaddrs,
  not internal getifaddrs implementation

* Fri Apr 01 2005 Florian La Roche <laroche@redhat.com>
- made perms for /var/lib/dhcpv6 the same

* Fri Mar 25 2005 Florian La Roche <laroche@redhat.com>
- add "exit 0" to postun script

* Thu Jan 13 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Fix misc. compiler warnings and ms-dos formatted man-pages

* Wed Jan 12 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Add 'prefix-delegation-interface' option to allow write
- of radvd interface configuration other than that for 
- the interface the lease was received on.

* Mon Jan 10 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Fix bug 144585: dhcp6c wasn't writing radvd.conf in prefix delegation mode

* Sun Jan 9  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Add Relay Agent support. Thanks to  Brian Bluesker<bbuesker@qualcomm.com>
- for the patch to add relay support to the server and for submitting the 
- patch originally contributed by Cristian Cadar of NEC Europe to 
- DHCPv6-developer  mailing list.

* Fri Jan 7  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-9
- fix bug 143728: SEGV core on resolv.conf + radvd.conf update -
- yywrap()'s must return 1

* Mon Oct 18 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-7
- fix bug 136146: clean up code - prevent compiler warnings

* Mon Sep 13 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-6
- fix bug 132468 for bug 125712: invoke change_resolv_conf

* Mon Sep 13 2004 Bill Nottingham <notting@redhat.com> - 0.10-5
- don't run by default
- add chkconfig prereqs, postun script, etc.

* Thu Sep  2 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-3/4
- fixed missing %defattr for dhcpv6_client - bug 131638

* Mon Aug 30 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-2
- Split into two packages: dhcpv6-*, containing server only,
- and dhcpv6_client-*, containing client only.

* Thu Aug 26 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-1 
- Initial build.

